<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="210"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="211"/>
      <source>Add tool</source>
      <translation>新增工具</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="212"/>
      <source>Add a tool shape to the robot</source>
      <translation>於機器人上增加工具造型</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="154"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="155"/>
      <source>Place robot...</source>
      <translation>放置機器人...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="156"/>
      <source>Place a robot (experimental!)</source>
      <translation>放置一個機器人(測試!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="55"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="56"/>
      <source>Create trajectory</source>
      <translation>建立軌跡</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="57"/>
      <source>Create a new empty trajectory</source>
      <translation>建立新的空白軌跡</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="314"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="315"/>
      <source>Edge to Trajectory...</source>
      <translation>邊至軌跡...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="316"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>由一組邊產生軌跡</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="46"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="47"/>
      <source>Kuka compact subroutine...</source>
      <translation>Kuka精簡子程式...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="48"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>以精簡KRL子程式匯出軌跡</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location filename="../../CommandExport.cpp" line="108"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="109"/>
      <source>Kuka full subroutine...</source>
      <translation>Kuka完整子程式...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="110"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>以完整KRL子程式匯出軌跡</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="169"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="170"/>
      <source>Kuka IR125</source>
      <translation>Kuka IR125</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="171"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>於此文件中插入Kula IR125</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="88"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="89"/>
      <source>Kuka IR16</source>
      <translation>Kuka IR16</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="90"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>於此文件中插入Kula IR16</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="129"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="130"/>
      <source>Kuka IR210</source>
      <translation>Kuka IR210</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="131"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>於此文件中插入Kula IR210</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="46"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="47"/>
      <source>Kuka IR500</source>
      <translation>Kuka IR500</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="48"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>於此文件中插入Kula IR500</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="88"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="89"/>
      <source>Insert in trajectory</source>
      <translation>於軌跡中插入</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="90"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>插入機器人工具位置至軌跡中</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="145"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="146"/>
      <source>Insert in trajectory</source>
      <translation>於軌跡中插入</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="147"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>插入預選位置至軌跡(W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="100"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <location filename="../../Command.cpp" line="102"/>
      <source>Move to home</source>
      <translation>移動至原點</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="209"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="210"/>
      <source>Set default orientation</source>
      <translation>設定預設方向</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="211"/>
      <source>Set the default orientation for subsequent commands for waypoint creation</source>
      <translation>設定預設的方向為後續建立航點的命令</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="248"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="249"/>
      <source>Set default values</source>
      <translation>設定預設值</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="250"/>
      <source>Set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>設定預設值給速率, 加速度和連續性為了後續命令建立新航點</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <location filename="../../Command.cpp" line="53"/>
      <source>Set the home position</source>
      <translation>設定原點位置</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location filename="../../Command.cpp" line="195"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="196"/>
      <source>Simulate a trajectory</source>
      <translation>模擬軌跡</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="197"/>
      <source>Run a simulation on a trajectory</source>
      <translation>於軌跡上進行模擬</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="425"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="426"/>
      <source>Trajectory compound...</source>
      <translation>軌跡物件...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="427"/>
      <source>Group and connect some trajectories to one</source>
      <translation>連結並群組數個軌跡成一個</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="378"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="379"/>
      <source>Dress-up trajectory...</source>
      <translation>修改軌跡</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="380"/>
      <source>Create a dress-up object which overrides some aspects of a trajectory</source>
      <translation>建立覆蓋軌跡部分設定的修改物件</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="51"/>
      <source>Trajectory tools</source>
      <translation>軌跡工具</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="52"/>
      <source>Robot tools</source>
      <translation>機器人設定工具</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="53"/>
      <source>Insert Robot</source>
      <translation>插入機器人</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="229"/>
      <location filename="../../CommandTrajectory.cpp" line="104"/>
      <location filename="../../CommandTrajectory.cpp" line="160"/>
      <location filename="../../CommandTrajectory.cpp" line="177"/>
      <location filename="../../CommandTrajectory.cpp" line="406"/>
      <location filename="../../Command.cpp" line="71"/>
      <location filename="../../Command.cpp" line="120"/>
      <location filename="../../Command.cpp" line="220"/>
      <location filename="../../Command.cpp" line="249"/>
      <location filename="../../CommandExport.cpp" line="61"/>
      <location filename="../../CommandExport.cpp" line="123"/>
      <source>Wrong selection</source>
      <translation>錯誤的選取</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <source>Select one Robot to set home position</source>
      <translation>選擇要設置起始位置之機器人</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="121"/>
      <source>Select one Robot</source>
      <translation>選取一機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="105"/>
      <location filename="../../Command.cpp" line="221"/>
      <location filename="../../Command.cpp" line="250"/>
      <location filename="../../CommandExport.cpp" line="62"/>
      <location filename="../../CommandExport.cpp" line="124"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>選取一個機器人和一軌跡物件</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="226"/>
      <source>Trajectory not valid</source>
      <translation>無效軌跡</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="227"/>
      <source>You need at least two waypoints in a trajectory to simulate.</source>
      <translation>軌跡中至少需要兩個航路點才能進行模擬.</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="84"/>
      <location filename="../../CommandExport.cpp" line="146"/>
      <source>KRL file</source>
      <translation>KRL 檔</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="85"/>
      <location filename="../../CommandExport.cpp" line="147"/>
      <source>All Files</source>
      <translation>所有檔案</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="86"/>
      <location filename="../../CommandExport.cpp" line="148"/>
      <source>Export program</source>
      <translation>匯出程式</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="230"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>選取一個機器人和一造型或VRML物件</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="161"/>
      <location filename="../../CommandTrajectory.cpp" line="178"/>
      <source>Select one Trajectory object.</source>
      <translation>選取一軌跡物件</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="184"/>
      <source>No preselection</source>
      <translation>無預選</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="185"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>您需要將滑鼠停留於幾何(預選)上方來使用此功能,相系說明請查詢文件</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="262"/>
      <source>Set default speed</source>
      <translation>設定預設的速率</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="263"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>速度：(e.g. 1 m/s or 3 cm/s)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="272"/>
      <source>Set default continuity</source>
      <translation>設定預設的連續性</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="273"/>
      <source>continuous ?</source>
      <translation>連續?</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="279"/>
      <source>Set default acceleration</source>
      <translation>設定預設加速度</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="280"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>加速度：(e.g. 1 m/s^2 or 3 cm/s^2)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="407"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>選取您想要修改的軌跡</translation>
    </message>
    <message>
      <location filename="../../ViewProviderTrajectory.cpp" line="149"/>
      <source>Modify</source>
      <translation>修改</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="79"/>
      <source>No robot files installed</source>
      <translation>無安裝之機器人檔案</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="80"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>請參照%1並複製至檔案%2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="20"/>
      <source>Simulation</source>
      <translation>模擬</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="272"/>
      <source>Type</source>
      <translation>類型</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="277"/>
      <source>Name</source>
      <translation>名稱</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="282"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="287"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="292"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="42"/>
      <source>TaskEdge2TracParameter</source>
      <translation type="unfinished">TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="22"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="69"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="116"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="163"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="210"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="257"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="313"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP：(200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="329"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>工具： (0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="41"/>
      <source>TaskRobot6Axis</source>
      <translation type="unfinished">TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="35"/>
      <source>TaskRobotControl</source>
      <translation type="unfinished">TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="35"/>
      <source>TaskRobotMessages</source>
      <translation type="unfinished">TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="20"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="254"/>
      <source>10 ms</source>
      <translation>10毫秒</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="259"/>
      <source>50 ms</source>
      <translation>50毫秒</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="264"/>
      <source>100 ms</source>
      <translation>100毫秒</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="269"/>
      <source>500 ms</source>
      <translation>500毫秒</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="274"/>
      <source>1 s</source>
      <translation>1秒</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="291"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>位置：(200.23, 300.23, 400.23, 234, 343 ,343)</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="317"/>
      <source>Type</source>
      <translation>類型</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="322"/>
      <source>Name</source>
      <translation>名稱</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="327"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="332"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="337"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="37"/>
      <source>Trajectory</source>
      <translation type="unfinished">Trajectory</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="41"/>
      <source>Dress Up Parameter</source>
      <translation type="unfinished">Dress Up Parameter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="29"/>
      <source>Hide / Show</source>
      <translation>隱藏/顯示</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="47"/>
      <source>Edges: 0</source>
      <translation>邊： 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="61"/>
      <source>Cluster: 0</source>
      <translation>群組：0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="72"/>
      <source>Sizing Value:</source>
      <translation>尺寸值：</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="103"/>
      <source>Use orientation of edge</source>
      <translation>使用邊之方向</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="37"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="56"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="75"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="94"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="113"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="132"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="151"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="170"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="189"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="208"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="227"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="246"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="258"/>
      <source>Tool 0</source>
      <translation>工具0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="263"/>
      <source>Tool</source>
      <translation>工具</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="268"/>
      <source>Base 0</source>
      <translation>基礎0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="273"/>
      <source>Base</source>
      <translation>基礎</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="278"/>
      <source>World</source>
      <translation>世界</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="287"/>
      <source>50mm / 5°</source>
      <translation>50mm / 5°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="292"/>
      <source>20mm / 2°</source>
      <translation>20mm / 2°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="297"/>
      <source>10mm / 1°</source>
      <translation>10mm / 1°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="302"/>
      <source>5mm / 0.5°</source>
      <translation>5mm / 0.5°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="307"/>
      <source>1mm / 0.1°</source>
      <translation>1mm / 0.1°</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="20"/>
      <source>clear</source>
      <translation>清除</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="20"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>速度 &amp; 加速度：</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="29"/>
      <source>Speed:</source>
      <translation>速度：</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="55"/>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="92"/>
      <source>Use</source>
      <translation>使用</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="66"/>
      <source>Accel:</source>
      <translation>加速：</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="102"/>
      <source>Don't change Cont</source>
      <translation>不要改變內容</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="107"/>
      <source>Continues</source>
      <translation>繼續</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="112"/>
      <source>Discontinues</source>
      <translation>中止</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="127"/>
      <source>Position and Orientation:</source>
      <translation>位置和方向：</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="159"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>不要更改位置和方向</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="164"/>
      <source>Use Orientation</source>
      <translation>使用定向</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="169"/>
      <source>Add Position</source>
      <translation>增加位置</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="174"/>
      <source>Add Orientation</source>
      <translation>增加方向</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="47"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="48"/>
      <source>Insert Robots</source>
      <translation>插入機器人</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="49"/>
      <source>&amp;Robot</source>
      <translation>&amp;機器人</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="50"/>
      <source>Export trajectory</source>
      <translation>匯出軌跡</translation>
    </message>
  </context>
</TS>
